SET @OLD_UNIQUE_CHECKS=@@UNIQUE_CHECKS, UNIQUE_CHECKS=0;
SET @OLD_FOREIGN_KEY_CHECKS=@@FOREIGN_KEY_CHECKS, FOREIGN_KEY_CHECKS=0;
SET @OLD_SQL_MODE=@@SQL_MODE, SQL_MODE='TRADITIONAL';

CREATE SCHEMA IF NOT EXISTS `csaOcean` DEFAULT CHARACTER SET utf8 COLLATE utf8_unicode_ci ;
USE `csaOcean` ;

-- -----------------------------------------------------
-- Table `csaOcean`.`notificationgroup`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `csaOcean`.`notificationgroup` (
  `xNotificationGroup` INT NOT NULL AUTO_INCREMENT ,
  `Name` VARCHAR(100) NULL ,
  `DefaultGroup` ENUM('n','y') NULL DEFAULT 'n' ,
  `Created` DATETIME NULL ,
  `Updated` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP ,
  PRIMARY KEY (`xNotificationGroup`) )
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `csaOcean`.`carrier`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `csaOcean`.`carrier` (
  `xCarrier` INT NOT NULL ,
  `Name` VARCHAR(50) NULL ,
  `Code` VARCHAR(10) NULL ,
  `xParentCarrier` INT NULL ,
  `Created` DATETIME NULL ,
  `Updated` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP ,
  PRIMARY KEY (`xCarrier`) )
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `csaOcean`.`incoterm`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `csaOcean`.`incoterm` (
  `xIncoterm` INT NOT NULL AUTO_INCREMENT ,
  `Code` VARCHAR(3) NULL ,
  `Description` VARCHAR(100) NULL ,
  `Created` DATETIME NULL ,
  `Updated` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP ,
  PRIMARY KEY (`xIncoterm`) )
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `csaOcean`.`country`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `csaOcean`.`country` (
  `xCountry` INT NOT NULL ,
  `Name` VARCHAR(50) NULL ,
  `OfficialName` VARCHAR(50) NULL ,
  `Code_2` CHAR(2) NULL ,
  `Code_3` CHAR(3) NULL ,
  `Numeric` SMALLINT(5) NULL ,
  `xCurrency` INT NULL ,
  `Created` DATETIME NULL ,
  `Updated` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP ,
  PRIMARY KEY (`xCountry`) )
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `csaOcean`.`port`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `csaOcean`.`port` (
  `xPort` INT NOT NULL AUTO_INCREMENT ,
  `Name` VARCHAR(50) NULL ,
  `Code` VARCHAR(10) NULL ,
  `xCountry` INT NOT NULL ,
  `xRegion` INT NULL ,
  `Created` DATETIME NULL ,
  `Updated` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP ,
  PRIMARY KEY (`xPort`) ,
  INDEX `xcountry1` (`xCountry` ASC) ,
  CONSTRAINT `xcountry1`
    FOREIGN KEY (`xCountry` )
    REFERENCES `csaOcean`.`country` (`xCountry` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `csaOcean`.`portloading`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `csaOcean`.`portloading` (
  `xPortLoading` INT NOT NULL AUTO_INCREMENT ,
  `xPort` INT NOT NULL ,
  `Created` DATETIME NULL ,
  `Updated` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP ,
  PRIMARY KEY (`xPortLoading`) ,
  INDEX `xport2` (`xPort` ASC) ,
  CONSTRAINT `xport2`
    FOREIGN KEY (`xPort` )
    REFERENCES `csaOcean`.`port` (`xPort` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `csaOcean`.`portdischarge`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `csaOcean`.`portdischarge` (
  `xPortDischarge` INT NOT NULL AUTO_INCREMENT ,
  `xPort` INT NOT NULL ,
  `Created` DATETIME NULL ,
  `Updated` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP ,
  PRIMARY KEY (`xPortDischarge`) ,
  INDEX `xport1` (`xPort` ASC) ,
  CONSTRAINT `xport1`
    FOREIGN KEY (`xPort` )
    REFERENCES `csaOcean`.`port` (`xPort` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `csaOcean`.`order`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `csaOcean`.`order` (
  `xOrder` INT NOT NULL AUTO_INCREMENT ,
  `Origin` VARCHAR(50) NULL ,
  `FinalDestination` VARCHAR(50) NULL ,
  `ShippingWindowFrom` DATE NULL ,
  `ShippingWindowTo` DATE NULL ,
  `ArrivalWindowFrom` DATE NULL ,
  `ArrivalWindowTo` DATE NULL ,
  `CustomerDate1From` DATE NULL ,
  `CustomerDate1To` DATE NULL ,
  `CustomerDate2From` DATE NULL ,
  `CustomerDate2To` DATE NULL ,
  `Remark` TEXT NULL ,
  `xPortLoading` INT NOT NULL ,
  `xPortDischarge` INT NOT NULL ,
  `xCarrier` INT NOT NULL ,
  `xIncoterm` INT NOT NULL ,
  `xNotificationGroup` INT NOT NULL ,
  `Created` DATETIME NULL ,
  `Updated` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP ,
  PRIMARY KEY (`xOrder`) ,
  INDEX `xnotificationgroup1` (`xNotificationGroup` ASC) ,
  INDEX `xcarrier2` (`xCarrier` ASC) ,
  INDEX `xincoterm1` (`xIncoterm` ASC) ,
  INDEX `xportloading2` (`xPortLoading` ASC) ,
  INDEX `xportdischarge2` (`xPortDischarge` ASC) ,
  CONSTRAINT `xnotificationgroup1`
    FOREIGN KEY (`xNotificationGroup` )
    REFERENCES `csaOcean`.`notificationgroup` (`xNotificationGroup` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `xcarrier2`
    FOREIGN KEY (`xCarrier` )
    REFERENCES `csaOcean`.`carrier` (`xCarrier` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `xincoterm1`
    FOREIGN KEY (`xIncoterm` )
    REFERENCES `csaOcean`.`incoterm` (`xIncoterm` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `xportloading2`
    FOREIGN KEY (`xPortLoading` )
    REFERENCES `csaOcean`.`portloading` (`xPortLoading` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `xportdischarge2`
    FOREIGN KEY (`xPortDischarge` )
    REFERENCES `csaOcean`.`portdischarge` (`xPortDischarge` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `csaOcean`.`booking`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `csaOcean`.`booking` (
  `xBooking` INT NOT NULL AUTO_INCREMENT ,
  `Created` DATETIME NULL COMMENT '		' ,
  `Updated` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP ,
  PRIMARY KEY (`xBooking`) )
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `csaOcean`.`packagetype`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `csaOcean`.`packagetype` (
  `xPackageType` INT NOT NULL AUTO_INCREMENT ,
  `Code` VARCHAR(10) NULL ,
  `Description` VARCHAR(50) NULL ,
  `Created` DATETIME NULL ,
  `Updated` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP ,
  PRIMARY KEY (`xPackageType`) )
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `csaOcean`.`orderitem`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `csaOcean`.`orderitem` (
  `xOrderItem` INT NOT NULL AUTO_INCREMENT ,
  `CommodityId` INT NULL ,
  `CommodityText` VARCHAR(50) NULL ,
  `NoPcs` INT NULL ,
  `NoPkgs` INT NULL ,
  `Volume` DECIMAL(12,2) NULL ,
  `Weight` DECIMAL(12,2) NULL ,
  `WeightNetto` DECIMAL(12,2) NULL ,
  `HSCode` INT NULL ,
  `xOrder` INT NOT NULL ,
  `xPackageType` INT NOT NULL ,
  `Created` DATETIME NULL ,
  `Updated` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP ,
  PRIMARY KEY (`xOrderItem`) ,
  INDEX `xorder2` (`xOrder` ASC) ,
  INDEX `xpackagetype1` (`xPackageType` ASC) ,
  CONSTRAINT `xorder2`
    FOREIGN KEY (`xOrder` )
    REFERENCES `csaOcean`.`order` (`xOrder` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `xpackagetype1`
    FOREIGN KEY (`xPackageType` )
    REFERENCES `csaOcean`.`packagetype` (`xPackageType` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `csaOcean`.`shippinginstruction`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `csaOcean`.`shippinginstruction` (
  `xShippingInstruction` INT NOT NULL AUTO_INCREMENT ,
  `Created` DATETIME NULL ,
  `Updated` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP ,
  PRIMARY KEY (`xShippingInstruction`) )
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `csaOcean`.`address`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `csaOcean`.`address` (
  `xAddress` INT NOT NULL AUTO_INCREMENT ,
  `CompanyName` VARCHAR(100) NOT NULL ,
  `Description` VARCHAR(100) NULL ,
  `Street` VARCHAR(70) NULL ,
  `ZipCode` VARCHAR(20) NULL ,
  `City` VARCHAR(70) NOT NULL ,
  `Phone` VARCHAR(50) NULL ,
  `Fax` VARCHAR(50) NULL ,
  `Email` VARCHAR(255) NULL ,
  `EORINo` VARCHAR(17) NULL ,
  `VatNo` VARCHAR(20) NULL ,
  `CompanyNo` INT NULL ,
  `SearchKey` VARCHAR(50) NULL ,
  `UserId` INT NULL ,
  `xCountry` INT NOT NULL ,
  `Created` DATETIME NULL ,
  `Updated` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP ,
  PRIMARY KEY (`xAddress`) ,
  INDEX `xcountry3` (`xCountry` ASC) ,
  CONSTRAINT `xcountry3`
    FOREIGN KEY (`xCountry` )
    REFERENCES `csaOcean`.`country` (`xCountry` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `csaOcean`.`person`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `csaOcean`.`person` (
  `xPerson` INT NOT NULL AUTO_INCREMENT ,
  `FirstName` VARCHAR(50) NULL ,
  `LastName` VARCHAR(50) NULL ,
  `Phone` VARCHAR(50) NULL ,
  `Fax` VARCHAR(50) NULL ,
  `Email` VARCHAR(255) NULL ,
  `xAddress` INT NOT NULL ,
  `Created` DATETIME NULL ,
  `Updated` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP ,
  PRIMARY KEY (`xPerson`) ,
  INDEX `xaddress1` (`xAddress` ASC) ,
  CONSTRAINT `xaddress1`
    FOREIGN KEY (`xAddress` )
    REFERENCES `csaOcean`.`address` (`xAddress` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `csaOcean`.`language`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `csaOcean`.`language` (
  `xLanguage` INT NOT NULL AUTO_INCREMENT ,
  `Code` VARCHAR(3) NULL ,
  `Description` VARCHAR(20) NULL ,
  `FilePath` VARCHAR(255) NULL ,
  `Created` DATETIME NULL ,
  `Updated` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP ,
  PRIMARY KEY (`xLanguage`) )
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `csaOcean`.`userrole`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `csaOcean`.`userrole` (
  `xUserRole` INT NOT NULL ,
  `Role` VARCHAR(20) NULL ,
  `ADGroup` VARCHAR(100) NULL ,
  `Description` VARCHAR(50) NULL ,
  `Created` DATETIME NULL ,
  `Updated` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP ,
  PRIMARY KEY (`xUserRole`) )
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `csaOcean`.`user`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `csaOcean`.`user` (
  `xUser` INT NOT NULL AUTO_INCREMENT ,
  `UserName` VARCHAR(50) NULL COMMENT '	' ,
  `FirstName` VARCHAR(50) NULL ,
  `LastName` VARCHAR(50) NULL ,
  `Phone` VARCHAR(50) NULL ,
  `Fax` VARCHAR(50) NULL ,
  `Email` VARCHAR(255) NULL ,
  `Order` ENUM('y','n') NULL ,
  `xUnitDefinition` INT NOT NULL ,
  `xLanguage` INT NOT NULL ,
  `xUserRole` INT NOT NULL ,
  `Created` DATETIME NULL ,
  `Updated` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP ,
  PRIMARY KEY (`xUser`, `xUnitDefinition`) ,
  INDEX `xlanguage1` (`xLanguage` ASC) ,
  INDEX `xuserrole1` (`xUserRole` ASC) ,
  CONSTRAINT `xlanguage1`
    FOREIGN KEY (`xLanguage` )
    REFERENCES `csaOcean`.`language` (`xLanguage` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `xuserrole1`
    FOREIGN KEY (`xUserRole` )
    REFERENCES `csaOcean`.`userrole` (`xUserRole` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `csaOcean`.`location`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `csaOcean`.`location` (
  `xLocation` INT NOT NULL AUTO_INCREMENT ,
  `CityName` VARCHAR(50) NULL ,
  `CityUnCode` VARCHAR(7) NULL ,
  `CitySchedkCode` VARCHAR(7) NULL ,
  `CityScheddCode` VARCHAR(7) NULL ,
  `StateCode` CHAR(3) NULL ,
  `StateName` VARCHAR(50) NULL ,
  `CountryName` VARCHAR(45) NULL ,
  `CountryUnCode` CHAR(3) NULL ,
  `Created` DATETIME NULL ,
  `Updated` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP ,
  PRIMARY KEY (`xLocation`) )
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `csaOcean`.`warehouse`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `csaOcean`.`warehouse` (
  `xWarehouse` INT NOT NULL AUTO_INCREMENT ,
  `Description` VARCHAR(50) NULL ,
  `Location` VARCHAR(100) NULL ,
  `Created` DATETIME NULL ,
  `Updated` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP ,
  `location_xLocation` INT NOT NULL ,
  PRIMARY KEY (`xWarehouse`) ,
  INDEX `xlocation1` (`location_xLocation` ASC) ,
  CONSTRAINT `xlocation1`
    FOREIGN KEY (`location_xLocation` )
    REFERENCES `csaOcean`.`location` (`xLocation` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `csaOcean`.`ordertemplate`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `csaOcean`.`ordertemplate` (
  `xOrderTemplate` INT NOT NULL AUTO_INCREMENT ,
  `TemplateName` VARCHAR(50) NULL ,
  `Origin` VARCHAR(50) NULL ,
  `FinalDestination` VARCHAR(50) NULL ,
  `ShippingWindowFrom` DATE NULL ,
  `ShippingWindowTo` DATE NULL ,
  `ArrivalWindowFrom` DATE NULL ,
  `ArrivalWindowTo` DATE NULL ,
  `CustomerDate1From` DATE NULL ,
  `CustomerDate1To` DATE NULL ,
  `CustomerDate2From` DATE NULL ,
  `CustomerDate2To` DATE NULL ,
  `xPortLoading` INT NOT NULL ,
  `xPortDischarge` INT NOT NULL ,
  `xNotificationGroup` INT NOT NULL ,
  `xCarrier` INT NOT NULL ,
  `xIncoterm` INT NOT NULL ,
  `Created` DATETIME NULL ,
  `Updated` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP ,
  PRIMARY KEY (`xOrderTemplate`) ,
  INDEX `xcarrier3` (`xCarrier` ASC) ,
  INDEX `xincoterm2` (`xIncoterm` ASC) ,
  INDEX `xnotificationgroup3` (`xNotificationGroup` ASC) ,
  INDEX `xportloading1` (`xPortLoading` ASC) ,
  INDEX `xportdischarge1` (`xPortDischarge` ASC) ,
  CONSTRAINT `xcarrier3`
    FOREIGN KEY (`xCarrier` )
    REFERENCES `csaOcean`.`carrier` (`xCarrier` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `xincoterm2`
    FOREIGN KEY (`xIncoterm` )
    REFERENCES `csaOcean`.`incoterm` (`xIncoterm` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `xnotificationgroup3`
    FOREIGN KEY (`xNotificationGroup` )
    REFERENCES `csaOcean`.`notificationgroup` (`xNotificationGroup` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `xportloading1`
    FOREIGN KEY (`xPortLoading` )
    REFERENCES `csaOcean`.`portloading` (`xPortLoading` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `xportdischarge1`
    FOREIGN KEY (`xPortDischarge` )
    REFERENCES `csaOcean`.`portdischarge` (`xPortDischarge` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `csaOcean`.`ordertemplateitem`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `csaOcean`.`ordertemplateitem` (
  `xOrderTemplateItem` INT NOT NULL AUTO_INCREMENT ,
  `CommodityId` INT NULL ,
  `CommodityText` VARCHAR(50) NULL ,
  `NoPcs` INT NULL ,
  `NoPkgs` INT NULL ,
  `Volume` DECIMAL(12,2) NULL ,
  `Weight` DECIMAL(12,2) NULL ,
  `WeightNetto` DECIMAL(12,2) NULL ,
  `HSCode` INT NULL ,
  `xOrderTemplate` INT NOT NULL ,
  `xPackageType` INT NOT NULL ,
  `Created` DATETIME NULL ,
  `Updated` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP ,
  PRIMARY KEY (`xOrderTemplateItem`) ,
  INDEX `xordertemplate2` (`xOrderTemplate` ASC) ,
  INDEX `xpackagetype2` (`xPackageType` ASC) ,
  CONSTRAINT `xordertemplate2`
    FOREIGN KEY (`xOrderTemplate` )
    REFERENCES `csaOcean`.`ordertemplate` (`xOrderTemplate` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `xpackagetype2`
    FOREIGN KEY (`xPackageType` )
    REFERENCES `csaOcean`.`packagetype` (`xPackageType` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `csaOcean`.`article`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `csaOcean`.`article` (
  `xArticle` INT NOT NULL AUTO_INCREMENT ,
  `Number` INT NULL ,
  `Description` VARCHAR(50) NOT NULL ,
  `Length` DECIMAL(12,2) NULL ,
  `Heigth` DECIMAL(12,2) NULL ,
  `Width` DECIMAL(12,2) NULL ,
  `PcsPkgs` INT NULL ,
  `PkgsPallet` INT NULL ,
  `Weight` DECIMAL(12,2) NULL ,
  `WeightNetto` DECIMAL(12,2) NULL ,
  `AdDescription` VARCHAR(50) NULL ,
  `CsField1` VARCHAR(50) NULL ,
  `CsField2` VARCHAR(50) NULL ,
  `CsField3` VARCHAR(50) NULL ,
  `HSCode` INT NULL ,
  `UserId` INT NULL ,
  `xPackageType` INT NOT NULL ,
  `xOrderItem` INT NOT NULL ,
  `xOrderTemplateItem` INT NOT NULL ,
  `Created` DATETIME NULL ,
  `Updated` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP ,
  PRIMARY KEY (`xArticle`) ,
  INDEX `xorderitem1` (`xOrderItem` ASC) ,
  INDEX `xordertemplateitem1` (`xOrderTemplateItem` ASC) ,
  INDEX `xpackagetype5` (`xPackageType` ASC) ,
  CONSTRAINT `xorderitem1`
    FOREIGN KEY (`xOrderItem` )
    REFERENCES `csaOcean`.`orderitem` (`xOrderItem` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `xordertemplateitem1`
    FOREIGN KEY (`xOrderTemplateItem` )
    REFERENCES `csaOcean`.`ordertemplateitem` (`xOrderTemplateItem` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `xpackagetype5`
    FOREIGN KEY (`xPackageType` )
    REFERENCES `csaOcean`.`packagetype` (`xPackageType` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `csaOcean`.`report`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `csaOcean`.`report` (
  `xReport` INT NOT NULL AUTO_INCREMENT ,
  `Type` VARCHAR(45) NULL ,
  `Owner` VARCHAR(45) NULL ,
  `Title` VARCHAR(45) NULL ,
  `TextSize` VARCHAR(45) NULL ,
  `Structure` VARCHAR(45) NULL ,
  `Created` DATETIME NULL ,
  `Updated` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP ,
  PRIMARY KEY (`xReport`) )
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `csaOcean`.`bookingdocumenttype`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `csaOcean`.`bookingdocumenttype` (
  `XBookingDocumentType` INT NOT NULL AUTO_INCREMENT ,
  `Title` VARCHAR(30) NULL ,
  `Created` DATETIME NULL ,
  `Updated` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP ,
  PRIMARY KEY (`XBookingDocumentType`) )
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `csaOcean`.`document`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `csaOcean`.`document` (
  `xDocument` INT NOT NULL AUTO_INCREMENT ,
  `xBookingDocumentType` INT NOT NULL ,
  `Created` DATETIME NULL ,
  `Updated` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP ,
  PRIMARY KEY (`xDocument`) ,
  INDEX `xbookingdocumenttype1` (`xBookingDocumentType` ASC) ,
  CONSTRAINT `xbookingdocumenttype1`
    FOREIGN KEY (`xBookingDocumentType` )
    REFERENCES `csaOcean`.`bookingdocumenttype` (`XBookingDocumentType` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `csaOcean`.`bookingdocument`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `csaOcean`.`bookingdocument` (
  `xBookingDocument` INT NOT NULL AUTO_INCREMENT ,
  `Name` VARCHAR(50) NULL ,
  `Path` VARCHAR(255) NULL ,
  `IssueDate` DATE NULL ,
  `Remark` LONGTEXT NULL ,
  `TelexDate` DATE NULL ,
  `UserId` INT NULL ,
  `xBooking` INT NOT NULL ,
  `xDocument` INT NOT NULL ,
  `Created` DATE NULL ,
  `Updated` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP ,
  PRIMARY KEY (`xBookingDocument`) ,
  INDEX `xbooking5` (`xBooking` ASC) ,
  INDEX `xdocument1` (`xDocument` ASC) ,
  CONSTRAINT `xbooking5`
    FOREIGN KEY (`xBooking` )
    REFERENCES `csaOcean`.`booking` (`xBooking` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `xdocument1`
    FOREIGN KEY (`xDocument` )
    REFERENCES `csaOcean`.`document` (`xDocument` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `csaOcean`.`referencetyp`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `csaOcean`.`referencetyp` (
  `xReferenceTyp` INT NOT NULL AUTO_INCREMENT ,
  `Typ` VARCHAR(50) NULL ,
  `Created` DATETIME NULL ,
  `Updated` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP ,
  PRIMARY KEY (`xReferenceTyp`) )
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `csaOcean`.`referencecategory`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `csaOcean`.`referencecategory` (
  `xReferenceCategory` INT NOT NULL ,
  `Name` VARCHAR(30) NULL ,
  `Created` DATETIME NULL ,
  `Updated` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP ,
  PRIMARY KEY (`xReferenceCategory`) )
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `csaOcean`.`reference`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `csaOcean`.`reference` (
  `xReference` INT NOT NULL AUTO_INCREMENT ,
  `Value` VARCHAR(50) NULL ,
  `xReferenceTyp` INT NOT NULL ,
  `xOrder` INT NOT NULL ,
  `xReferenceCategory` INT NOT NULL ,
  `xBooking` INT NOT NULL ,
  `Created` DATETIME NULL ,
  `Updated` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP ,
  PRIMARY KEY (`xReference`) ,
  INDEX `xreferencetyp1` (`xReferenceTyp` ASC) ,
  INDEX `xorder1` (`xOrder` ASC) ,
  INDEX `xreferencecategory1` (`xReferenceCategory` ASC) ,
  INDEX `xbooking3` (`xBooking` ASC) ,
  CONSTRAINT `xreferencetyp1`
    FOREIGN KEY (`xReferenceTyp` )
    REFERENCES `csaOcean`.`referencetyp` (`xReferenceTyp` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `xorder1`
    FOREIGN KEY (`xOrder` )
    REFERENCES `csaOcean`.`order` (`xOrder` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `xreferencecategory1`
    FOREIGN KEY (`xReferenceCategory` )
    REFERENCES `csaOcean`.`referencecategory` (`xReferenceCategory` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `xbooking3`
    FOREIGN KEY (`xBooking` )
    REFERENCES `csaOcean`.`booking` (`xBooking` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `csaOcean`.`addresstypecategory`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `csaOcean`.`addresstypecategory` (
  `xAddressTypeCategory` INT NOT NULL AUTO_INCREMENT ,
  `Value` VARCHAR(50) NULL ,
  `Created` DATETIME NULL ,
  `Updated` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP ,
  PRIMARY KEY (`xAddressTypeCategory`) )
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `csaOcean`.`addresstype`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `csaOcean`.`addresstype` (
  `XOrderAddressType` INT NOT NULL AUTO_INCREMENT ,
  `Title` VARCHAR(45) NULL ,
  `xAddressTypeCategory` INT NOT NULL ,
  `Created` DATETIME NULL ,
  `Updated` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP ,
  PRIMARY KEY (`XOrderAddressType`) ,
  INDEX `xaddresstypcategory1` (`xAddressTypeCategory` ASC) ,
  CONSTRAINT `xaddresstypcategory1`
    FOREIGN KEY (`xAddressTypeCategory` )
    REFERENCES `csaOcean`.`addresstypecategory` (`xAddressTypeCategory` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `csaOcean`.`orderaddress`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `csaOcean`.`orderaddress` (
  `xOrderAddress` INT NOT NULL AUTO_INCREMENT ,
  `CompanyName` VARCHAR(100) NULL ,
  `Description` VARCHAR(100) NULL ,
  `Street` VARCHAR(70) NULL ,
  `ZipCode` VARCHAR(20) NULL ,
  `City` VARCHAR(70) NULL ,
  `Phone` VARCHAR(50) NULL ,
  `Fax` VARCHAR(50) NULL ,
  `Email` VARCHAR(255) NULL ,
  `EORINo` VARCHAR(17) NULL ,
  `VatNo` VARCHAR(20) NULL ,
  `CompanyNo` INT NULL ,
  `SearchKey` VARCHAR(50) NULL ,
  `xCountry` INT NOT NULL ,
  `XAddressTypeCategory` INT NOT NULL ,
  `xOrder` INT NOT NULL ,
  `Created` DATETIME NULL ,
  `Updated` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP ,
  PRIMARY KEY (`xOrderAddress`) ,
  INDEX `xorder3` (`xOrder` ASC) ,
  INDEX `xorderaddresstype1` (`XAddressTypeCategory` ASC) ,
  INDEX `xcountry4` (`xCountry` ASC) ,
  CONSTRAINT `xorder3`
    FOREIGN KEY (`xOrder` )
    REFERENCES `csaOcean`.`order` (`xOrder` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `xorderaddresstype1`
    FOREIGN KEY (`XAddressTypeCategory` )
    REFERENCES `csaOcean`.`addresstype` (`XOrderAddressType` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `xcountry4`
    FOREIGN KEY (`xCountry` )
    REFERENCES `csaOcean`.`country` (`xCountry` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `csaOcean`.`containerunit`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `csaOcean`.`containerunit` (
  `xContainerUnit` INT NOT NULL AUTO_INCREMENT ,
  `Code` VARCHAR(10) NULL ,
  `Description` VARCHAR(50) NULL ,
  `Teu` FLOAT NULL DEFAULT 1 ,
  `Created` DATETIME NULL ,
  `Updated` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP ,
  PRIMARY KEY (`xContainerUnit`) )
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `csaOcean`.`bookingcontainer`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `csaOcean`.`bookingcontainer` (
  `xBookingContainer` INT NOT NULL AUTO_INCREMENT ,
  `Count` INT NULL ,
  `xBooking` INT NOT NULL ,
  `xContainerUnit` INT NOT NULL ,
  `Created` DATETIME NULL ,
  `Updated` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP ,
  PRIMARY KEY (`xBookingContainer`) ,
  INDEX `xbooking1` (`xBooking` ASC) ,
  INDEX `xcontainerunit1` (`xContainerUnit` ASC) ,
  CONSTRAINT `xbooking1`
    FOREIGN KEY (`xBooking` )
    REFERENCES `csaOcean`.`booking` (`xBooking` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `xcontainerunit1`
    FOREIGN KEY (`xContainerUnit` )
    REFERENCES `csaOcean`.`containerunit` (`xContainerUnit` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `csaOcean`.`vessel`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `csaOcean`.`vessel` (
  `xVessel` INT NOT NULL AUTO_INCREMENT ,
  `Vessel` VARCHAR(50) NULL ,
  `Voyage` VARCHAR(20) NULL ,
  `xCarrier` INT NOT NULL ,
  `Created` DATETIME NULL ,
  `Updated` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP ,
  PRIMARY KEY (`xVessel`) ,
  INDEX `xcarrier1` (`xCarrier` ASC) ,
  CONSTRAINT `xcarrier1`
    FOREIGN KEY (`xCarrier` )
    REFERENCES `csaOcean`.`carrier` (`xCarrier` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `csaOcean`.`bookingvessel`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `csaOcean`.`bookingvessel` (
  `xBookingVessel` INT NOT NULL AUTO_INCREMENT ,
  `PortOfReceipt` VARCHAR(50) NULL ,
  `FinalDestination` VARCHAR(50) NULL ,
  `PlaceOfDelivery` VARCHAR(50) NULL ,
  `CarrierBookingNo` VARCHAR(30) NULL ,
  `SpaceConfirmed` DATETIME NULL ,
  `SpaceConfirmedSetBy` VARCHAR(255) NULL ,
  `ShippingApproved` DATETIME NULL ,
  `ShippingApprovedSetBy` VARCHAR(255) NULL ,
  `ApprovalConfirmed` DATETIME NULL ,
  `ApprovalConfirmedSetBy` VARCHAR(255) NULL ,
  `xPortLoading` INT NOT NULL ,
  `xPortDischarge` INT NOT NULL ,
  `xVessel` INT NOT NULL ,
  `xBooking` INT NOT NULL ,
  `Created` DATETIME NULL ,
  `Updated` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP ,
  PRIMARY KEY (`xBookingVessel`) ,
  INDEX `xbooking2` (`xBooking` ASC) ,
  INDEX `xvesselvoyage2` (`xVessel` ASC) ,
  INDEX `xportloading3` (`xPortLoading` ASC) ,
  INDEX `xportdischarge3` (`xPortDischarge` ASC) ,
  CONSTRAINT `xbooking2`
    FOREIGN KEY (`xBooking` )
    REFERENCES `csaOcean`.`booking` (`xBooking` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `xvesselvoyage2`
    FOREIGN KEY (`xVessel` )
    REFERENCES `csaOcean`.`vessel` (`xVessel` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `xportloading3`
    FOREIGN KEY (`xPortLoading` )
    REFERENCES `csaOcean`.`portloading` (`xPortLoading` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `xportdischarge3`
    FOREIGN KEY (`xPortDischarge` )
    REFERENCES `csaOcean`.`portdischarge` (`xPortDischarge` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `csaOcean`.`bookingitem`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `csaOcean`.`bookingitem` (
  `xBookingItem` INT NOT NULL AUTO_INCREMENT ,
  `CommodityId` INT NULL ,
  `CommodityText` VARCHAR(50) NULL ,
  `NoPcs` INT NULL ,
  `NoPkgs` INT NULL ,
  `Volume` DECIMAL(12,2) NULL ,
  `Weight` DECIMAL(12,2) NULL ,
  `HSCode` INT NULL ,
  `xBooking` INT NOT NULL ,
  `xOrderItem` INT NOT NULL ,
  `xPackageType` INT NOT NULL ,
  `Created` DATETIME NULL ,
  `Updated` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP ,
  PRIMARY KEY (`xBookingItem`) ,
  INDEX `xbooking4` (`xBooking` ASC) ,
  INDEX `xorderitem2` (`xOrderItem` ASC) ,
  INDEX `xpackagetype3` (`xPackageType` ASC) ,
  CONSTRAINT `xbooking4`
    FOREIGN KEY (`xBooking` )
    REFERENCES `csaOcean`.`booking` (`xBooking` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `xorderitem2`
    FOREIGN KEY (`xOrderItem` )
    REFERENCES `csaOcean`.`orderitem` (`xOrderItem` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `xpackagetype3`
    FOREIGN KEY (`xPackageType` )
    REFERENCES `csaOcean`.`packagetype` (`xPackageType` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `csaOcean`.`ordertemplateaddress`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `csaOcean`.`ordertemplateaddress` (
  `xOrderTemplateAddress` INT NOT NULL AUTO_INCREMENT ,
  `CompanyName` VARCHAR(100) NULL ,
  `Description` VARCHAR(100) NULL ,
  `Street` VARCHAR(70) NULL ,
  `ZipCode` VARCHAR(20) NULL ,
  `City` VARCHAR(70) NULL ,
  `Phone` VARCHAR(50) NULL ,
  `Fax` VARCHAR(50) NULL ,
  `Email` VARCHAR(255) NULL ,
  `EORIno` VARCHAR(17) NULL ,
  `VatNo` VARCHAR(20) NULL ,
  `CompanyNo` INT NULL ,
  `SearchKey` VARCHAR(50) NULL ,
  `xAddressTypCategory` INT NOT NULL ,
  `xOrderTemplate` INT NOT NULL ,
  `xCountry` INT NOT NULL ,
  `Created` DATETIME NULL ,
  `Updated` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP ,
  PRIMARY KEY (`xOrderTemplateAddress`) ,
  INDEX `xordertemplate1` (`xOrderTemplate` ASC) ,
  INDEX `xaddresstype3` (`xAddressTypCategory` ASC) ,
  INDEX `xcountry2` (`xCountry` ASC) ,
  CONSTRAINT `xordertemplate1`
    FOREIGN KEY (`xOrderTemplate` )
    REFERENCES `csaOcean`.`ordertemplate` (`xOrderTemplate` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `xaddresstype3`
    FOREIGN KEY (`xAddressTypCategory` )
    REFERENCES `csaOcean`.`addresstype` (`xAddressTypeCategory` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `xcountry2`
    FOREIGN KEY (`xCountry` )
    REFERENCES `csaOcean`.`country` (`xCountry` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `csaOcean`.`orderbooking`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `csaOcean`.`orderbooking` (
  `xOrderBooking` INT NOT NULL AUTO_INCREMENT ,
  `xOrder` INT NOT NULL ,
  `xBooking` INT NOT NULL ,
  `Created` DATETIME NULL ,
  `Updated` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP ,
  PRIMARY KEY (`xOrderBooking`) ,
  INDEX `xorder6` (`xOrder` ASC) ,
  INDEX `xbooking10` (`xBooking` ASC) ,
  CONSTRAINT `xorder6`
    FOREIGN KEY (`xOrder` )
    REFERENCES `csaOcean`.`order` (`xOrder` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `xbooking10`
    FOREIGN KEY (`xBooking` )
    REFERENCES `csaOcean`.`booking` (`xBooking` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `csaOcean`.`shippinginstructionitem`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `csaOcean`.`shippinginstructionitem` (
  `xShippingInstructionItem` INT NOT NULL AUTO_INCREMENT ,
  `ContainerNumber` VARCHAR(11) NULL ,
  `NoPcs` INT NULL ,
  `NoPkgs` INT NULL ,
  `Cbm` DECIMAL(12,2) NULL ,
  `Weight` DECIMAL(12,2) NULL ,
  `CargoDescription` VARCHAR(50) NULL ,
  `WeightNetto` DECIMAL(12,2) NULL ,
  `HSCode` INT NULL ,
  `SealNumber` VARCHAR(12) NULL ,
  `xContainerUnit` INT NOT NULL ,
  `xShippingInstruction` INT NOT NULL ,
  `xBookingContainer` INT NOT NULL ,
  `xPackageType` INT NOT NULL ,
  `xBookingItem` INT NOT NULL ,
  `Created` DATETIME NULL ,
  `Updated` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP ,
  PRIMARY KEY (`xShippingInstructionItem`) ,
  INDEX `xshippinginstruction1` (`xShippingInstruction` ASC) ,
  INDEX `xbookingcontainer1` (`xBookingContainer` ASC) ,
  INDEX `xpackagetype4` (`xPackageType` ASC) ,
  INDEX `xcontainerunit4` (`xContainerUnit` ASC) ,
  INDEX `xbookingitem1` (`xBookingItem` ASC) ,
  CONSTRAINT `xshippinginstruction1`
    FOREIGN KEY (`xShippingInstruction` )
    REFERENCES `csaOcean`.`shippinginstruction` (`xShippingInstruction` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `xbookingcontainer1`
    FOREIGN KEY (`xBookingContainer` )
    REFERENCES `csaOcean`.`bookingcontainer` (`xBookingContainer` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `xpackagetype4`
    FOREIGN KEY (`xPackageType` )
    REFERENCES `csaOcean`.`packagetype` (`xPackageType` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `xcontainerunit4`
    FOREIGN KEY (`xContainerUnit` )
    REFERENCES `csaOcean`.`containerunit` (`xContainerUnit` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `xbookingitem1`
    FOREIGN KEY (`xBookingItem` )
    REFERENCES `csaOcean`.`bookingitem` (`xBookingItem` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `csaOcean`.`status`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `csaOcean`.`status` (
  `xStatus` INT NOT NULL AUTO_INCREMENT ,
  `Code` INT NULL ,
  `Description` VARCHAR(50) NULL ,
  `Created` DATETIME NULL ,
  `Updated` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP ,
  PRIMARY KEY (`xStatus`) )
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `csaOcean`.`warehouseitem`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `csaOcean`.`warehouseitem` (
  `xWarehouseItem` INT NOT NULL AUTO_INCREMENT ,
  `ItemNumber` INT NULL ,
  `ItemDescription` VARCHAR(50) NULL ,
  `Po` VARCHAR(50) NULL ,
  `Customer` VARCHAR(100) NULL ,
  `PackageCount` INT NULL ,
  `DescriptionGoods` VARCHAR(100) NULL ,
  `Cbm` DECIMAL(12,2) NULL ,
  `Weight` DECIMAL(12,2) NULL ,
  `NumberPcs` INT NULL ,
  `PcsPkgs` INT NULL ,
  `InDate` DATETIME NULL ,
  `OutDate` DATETIME NULL ,
  `xWarehouse` INT NOT NULL ,
  `xStatus` INT NOT NULL ,
  `xPackageType` INT NOT NULL ,
  `Created` DATETIME NULL ,
  `Updated` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP ,
  PRIMARY KEY (`xWarehouseItem`) ,
  INDEX `xwarehouse1` (`xWarehouse` ASC) ,
  INDEX `xpackagetype6` (`xPackageType` ASC) ,
  INDEX `xstatus1` (`xStatus` ASC) ,
  CONSTRAINT `xwarehouse1`
    FOREIGN KEY (`xWarehouse` )
    REFERENCES `csaOcean`.`warehouse` (`xWarehouse` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `xpackagetype6`
    FOREIGN KEY (`xPackageType` )
    REFERENCES `csaOcean`.`packagetype` (`xPackageType` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `xstatus1`
    FOREIGN KEY (`xStatus` )
    REFERENCES `csaOcean`.`status` (`xStatus` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `csaOcean`.`customer`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `csaOcean`.`customer` (
  `xCustomer` INT NOT NULL ,
  `Name` VARCHAR(100) NULL ,
  `Code` VARCHAR(20) NULL ,
  `HideBoxFee` TINYINT(3) NULL ,
  `HideRawRate` TINYINT(3) NULL ,
  `xShareGroup` INT NULL ,
  `xCommodity` INT NULL ,
  `Created` DATETIME NULL COMMENT '	' ,
  `Updated` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP ,
  PRIMARY KEY (`xCustomer`) )
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `csaOcean`.`todogroup`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `csaOcean`.`todogroup` (
  `xTodoGroup` INT NOT NULL AUTO_INCREMENT ,
  `Name` VARCHAR(100) NULL ,
  `Devision` VARCHAR(50) NULL ,
  `PortType` VARCHAR(20) NULL ,
  `Active` ENUM('y','n') NULL ,
  `xCustomer` INT NOT NULL ,
  `Created` DATETIME NULL ,
  `Updated` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP ,
  PRIMARY KEY (`xTodoGroup`) ,
  INDEX `xcustomer1` (`xCustomer` ASC) ,
  CONSTRAINT `xcustomer1`
    FOREIGN KEY (`xCustomer` )
    REFERENCES `csaOcean`.`customer` (`xCustomer` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `csaOcean`.`todogroupitem`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `csaOcean`.`todogroupitem` (
  `xTodoGroupItem` INT NOT NULL AUTO_INCREMENT ,
  `Task` TEXT NULL ,
  `Done` VARCHAR(50) NULL ,
  `Auto` ENUM('y','n') NULL ,
  `Schedule` VARCHAR(100) NULL ,
  `xTodoGroup` INT NOT NULL ,
  `xBooking` INT NOT NULL ,
  `xOrder` INT NOT NULL ,
  `xUserRole` INT NOT NULL ,
  `Created` DATETIME NULL ,
  `Updated` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP ,
  PRIMARY KEY (`xTodoGroupItem`) ,
  INDEX `xtodogroup1` (`xTodoGroup` ASC) ,
  INDEX `xorder4` (`xOrder` ASC) ,
  INDEX `xbooking7` (`xBooking` ASC) ,
  INDEX `xuserrole2` (`xUserRole` ASC) ,
  CONSTRAINT `xtodogroup1`
    FOREIGN KEY (`xTodoGroup` )
    REFERENCES `csaOcean`.`todogroup` (`xTodoGroup` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `xorder4`
    FOREIGN KEY (`xOrder` )
    REFERENCES `csaOcean`.`order` (`xOrder` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `xbooking7`
    FOREIGN KEY (`xBooking` )
    REFERENCES `csaOcean`.`booking` (`xBooking` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `xuserrole2`
    FOREIGN KEY (`xUserRole` )
    REFERENCES `csaOcean`.`userrole` (`xUserRole` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `csaOcean`.`bookingaddress`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `csaOcean`.`bookingaddress` (
  `xBookingaddress` INT NOT NULL AUTO_INCREMENT ,
  `Value` VARCHAR(45) NULL ,
  `xBooking` INT NOT NULL ,
  `xAddressType` INT NOT NULL ,
  `Created` DATETIME NULL ,
  `Updated` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP ,
  PRIMARY KEY (`xBookingaddress`) ,
  INDEX `xbooking8` (`xBooking` ASC) ,
  INDEX `xaddresstype1` (`xAddressType` ASC) ,
  CONSTRAINT `xbooking8`
    FOREIGN KEY (`xBooking` )
    REFERENCES `csaOcean`.`booking` (`xBooking` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `xaddresstype1`
    FOREIGN KEY (`xAddressType` )
    REFERENCES `csaOcean`.`addresstype` (`xAddressTypeCategory` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `csaOcean`.`bookingremark`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `csaOcean`.`bookingremark` (
  `xBookingRemark` INT NOT NULL AUTO_INCREMENT ,
  `Remark` LONGTEXT NULL ,
  `UserId` INT NULL ,
  `Public` ENUM('y','n') NULL ,
  `xBooking` INT NOT NULL ,
  `Created` DATETIME NULL ,
  `Updated` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP ,
  PRIMARY KEY (`xBookingRemark`) ,
  INDEX `xbooking9` (`xBooking` ASC) ,
  CONSTRAINT `xbooking9`
    FOREIGN KEY (`xBooking` )
    REFERENCES `csaOcean`.`booking` (`xBooking` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `csaOcean`.`shippinginstructionaddress`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `csaOcean`.`shippinginstructionaddress` (
  `xShippingInstructionAddress` INT NOT NULL AUTO_INCREMENT ,
  `Value` LONGTEXT NULL ,
  `xShippingInstruction` INT NOT NULL ,
  `xAddressType` INT NOT NULL ,
  `Created` DATETIME NULL ,
  `Updated` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP ,
  PRIMARY KEY (`xShippingInstructionAddress`) ,
  INDEX `xshippinginstruction2` (`xShippingInstruction` ASC) ,
  INDEX `xaddresstype2` (`xAddressType` ASC) ,
  CONSTRAINT `xshippinginstruction2`
    FOREIGN KEY (`xShippingInstruction` )
    REFERENCES `csaOcean`.`shippinginstruction` (`xShippingInstruction` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `xaddresstype2`
    FOREIGN KEY (`xAddressType` )
    REFERENCES `csaOcean`.`addresstype` (`xAddressTypeCategory` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `csaOcean`.`loop`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `csaOcean`.`loop` (
  `xLoop` INT NOT NULL AUTO_INCREMENT ,
  `Name` VARCHAR(50) NULL ,
  `Created` DATETIME NULL ,
  `Updated` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP ,
  PRIMARY KEY (`xLoop`) )
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `csaOcean`.`loopport`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `csaOcean`.`loopport` (
  `xLoopPort` INT NOT NULL AUTO_INCREMENT ,
  `Sequence` INT NULL ,
  `Days` INT NULL ,
  `xPort` INT NOT NULL ,
  `xLoop` INT NOT NULL ,
  `Created` DATETIME NULL ,
  `Updated` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP ,
  PRIMARY KEY (`xLoopPort`) ,
  INDEX `xloop1` (`xLoop` ASC) ,
  INDEX `xport5` (`xPort` ASC) ,
  CONSTRAINT `xloop1`
    FOREIGN KEY (`xLoop` )
    REFERENCES `csaOcean`.`loop` (`xLoop` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `xport5`
    FOREIGN KEY (`xPort` )
    REFERENCES `csaOcean`.`port` (`xPort` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `csaOcean`.`vesselport`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `csaOcean`.`vesselport` (
  `xVesselPorts` INT NOT NULL AUTO_INCREMENT ,
  `Sequence` INT NULL ,
  `ETA` DATE NULL ,
  `ETD` DATE NULL ,
  `CyClosing` DATE NULL ,
  `xVessel` INT NOT NULL ,
  `xPort` INT NOT NULL ,
  `Created` DATETIME NULL ,
  `Updated` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP ,
  PRIMARY KEY (`xVesselPorts`) ,
  INDEX `xvesselvoyage1` (`xVessel` ASC) ,
  INDEX `xport4` (`xPort` ASC) ,
  CONSTRAINT `xvesselvoyage1`
    FOREIGN KEY (`xVessel` )
    REFERENCES `csaOcean`.`vessel` (`xVessel` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `xport4`
    FOREIGN KEY (`xPort` )
    REFERENCES `csaOcean`.`port` (`xPort` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `csaOcean`.`notificationgroupperson`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `csaOcean`.`notificationgroupperson` (
  `xNotificationGroupPerson` INT NOT NULL AUTO_INCREMENT ,
  `xNotificationGroup` INT NOT NULL ,
  `xPerson` INT NOT NULL ,
  `Created` DATETIME NULL ,
  `Updated` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP ,
  PRIMARY KEY (`xNotificationGroupPerson`) ,
  INDEX `xnotificationgroup2` (`xNotificationGroup` ASC) ,
  INDEX `xperson1` (`xPerson` ASC) ,
  CONSTRAINT `xnotificationgroup2`
    FOREIGN KEY (`xNotificationGroup` )
    REFERENCES `csaOcean`.`notificationgroup` (`xNotificationGroup` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `xperson1`
    FOREIGN KEY (`xPerson` )
    REFERENCES `csaOcean`.`person` (`xPerson` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `csaOcean`.`ordertemplatecontainer`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `csaOcean`.`ordertemplatecontainer` (
  `xOrderTemplateContainer` INT NOT NULL AUTO_INCREMENT ,
  `Count` INT NULL ,
  `xOrderTemplate` INT NOT NULL ,
  `xContainerUnit` INT NOT NULL ,
  `Created` DATETIME NULL ,
  `Updated` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP ,
  PRIMARY KEY (`xOrderTemplateContainer`) ,
  INDEX `xordertemplate3` (`xOrderTemplate` ASC) ,
  INDEX `xcontainerunit2` (`xContainerUnit` ASC) ,
  CONSTRAINT `xordertemplate3`
    FOREIGN KEY (`xOrderTemplate` )
    REFERENCES `csaOcean`.`ordertemplate` (`xOrderTemplate` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `xcontainerunit2`
    FOREIGN KEY (`xContainerUnit` )
    REFERENCES `csaOcean`.`containerunit` (`xContainerUnit` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `csaOcean`.`ordercontainer`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `csaOcean`.`ordercontainer` (
  `xOrderContainer` INT NOT NULL AUTO_INCREMENT ,
  `Count` INT NULL ,
  `xOrder` INT NOT NULL ,
  `xContainerUnit` INT NOT NULL ,
  `Created` DATETIME NULL ,
  `Updated` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP ,
  PRIMARY KEY (`xOrderContainer`) ,
  INDEX `xorder5` (`xOrder` ASC) ,
  INDEX `xcontainerunit3` (`xContainerUnit` ASC) ,
  CONSTRAINT `xorder5`
    FOREIGN KEY (`xOrder` )
    REFERENCES `csaOcean`.`order` (`xOrder` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `xcontainerunit3`
    FOREIGN KEY (`xContainerUnit` )
    REFERENCES `csaOcean`.`containerunit` (`xContainerUnit` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `csaOcean`.`bookingshippinginstruction`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `csaOcean`.`bookingshippinginstruction` (
  `xBookingshippinginstruction` INT NOT NULL AUTO_INCREMENT ,
  `xBooking` INT NOT NULL ,
  `xShippingInstruction` INT NOT NULL ,
  `Created` DATETIME NULL ,
  `Updated` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP ,
  PRIMARY KEY (`xBookingshippinginstruction`) ,
  INDEX `xbooking6` (`xBooking` ASC) ,
  INDEX `xshippinginstruction3` (`xShippingInstruction` ASC) ,
  CONSTRAINT `xbooking6`
    FOREIGN KEY (`xBooking` )
    REFERENCES `csaOcean`.`booking` (`xBooking` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `xshippinginstruction3`
    FOREIGN KEY (`xShippingInstruction` )
    REFERENCES `csaOcean`.`shippinginstruction` (`xShippingInstruction` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `csaOcean`.`loopcarrier`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `csaOcean`.`loopcarrier` (
  `xLoopCarrier` INT NOT NULL AUTO_INCREMENT ,
  `xLoop` INT NOT NULL ,
  `Created` DATETIME NULL ,
  `Updated` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP ,
  PRIMARY KEY (`xLoopCarrier`) ,
  INDEX `xloop2` (`xLoop` ASC) ,
  CONSTRAINT `xloop2`
    FOREIGN KEY (`xLoop` )
    REFERENCES `csaOcean`.`loop` (`xLoop` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `csaOcean`.`loopcarrierport`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `csaOcean`.`loopcarrierport` (
  `xLoopCarrierPort` INT NOT NULL AUTO_INCREMENT ,
  `xLoopCarrier` INT NOT NULL ,
  `xLoopPort` INT NOT NULL ,
  `Created` DATETIME NULL ,
  `Updated` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP ,
  PRIMARY KEY (`xLoopCarrierPort`) ,
  INDEX `xloopcarrier1` (`xLoopCarrier` ASC) ,
  INDEX `xloopport1` (`xLoopPort` ASC) ,
  CONSTRAINT `xloopcarrier1`
    FOREIGN KEY (`xLoopCarrier` )
    REFERENCES `csaOcean`.`loopcarrier` (`xLoopCarrier` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `xloopport1`
    FOREIGN KEY (`xLoopPort` )
    REFERENCES `csaOcean`.`loopport` (`xLoopPort` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;


-- -----------------------------------------------------
-- Table `csaOcean`.`todogroupport`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `csaOcean`.`todogroupport` (
  `xTodoGroupPort` INT NOT NULL AUTO_INCREMENT ,
  `xTodoGroup` INT NOT NULL ,
  `xPort` INT NOT NULL ,
  `Created` DATETIME NULL ,
  `Updated` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP ,
  PRIMARY KEY (`xTodoGroupPort`) ,
  INDEX `xtodogroup2` (`xTodoGroup` ASC) ,
  INDEX `xport3` (`xPort` ASC) ,
  CONSTRAINT `xtodogroup2`
    FOREIGN KEY (`xTodoGroup` )
    REFERENCES `csaOcean`.`todogroup` (`xTodoGroup` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `xport3`
    FOREIGN KEY (`xPort` )
    REFERENCES `csaOcean`.`port` (`xPort` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB;



SET SQL_MODE=@OLD_SQL_MODE;
SET FOREIGN_KEY_CHECKS=@OLD_FOREIGN_KEY_CHECKS;
SET UNIQUE_CHECKS=@OLD_UNIQUE_CHECKS;
